CLI Commands
============

Metapack Management Program
-------------------------------

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :maxdepth: 1
   
.. _mp_new: 

new: Creating New Packages
-----------------------------

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :start_command: new

update: Update Package Information
-------------------------------------

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :start_command: update


info: Show Information About Packages
----------------------------------------

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :start_command: info

    
run: Run Resources and Generate Tabular Data
-----------------------------------------------

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :start_command: run 
    

build: Building Packages
---------------------------

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :start_command: build
 
.. _mp_s3:  
    
s3: Store Packages in S3
---------------------------

.. autoprogram:: metapack.cli.mp:base_parser()
    :prog: mp
    :start_command: s3
